package main

import (
	"bytes"
	"io"
	"os/exec"
	"sync"
)

type sampleExecutionResult struct {
	Stdin        string
	Stdout       string
	Stderr       string
	ProcessError string
}

func runSample(cmd string, input io.Reader, output, stderr io.Writer) sampleExecutionResult {

	process := exec.Command(cmd)
	process.Env = []string{"SOI_H_EOFCHECK=1", "SOI_COLOR=1"}
	processStdin, err := process.StdinPipe()
	if err != nil {
		panic(err)
	}
	processStdout, err := process.StdoutPipe()
	if err != nil {
		panic(err)
	}
	processStderr, err := process.StderrPipe()
	if err != nil {
		panic(err)
	}
	var collectedStdin bytes.Buffer
	var collectedStdout bytes.Buffer
	var collectedStderr bytes.Buffer
	go func() {
		io.Copy(io.MultiWriter(processStdin, &collectedStdin), input)
		processStdin.Close()
	}()
	err = process.Start()
	if err != nil {
		panic(err)
	}

	var waitgroup sync.WaitGroup
	waitgroup.Add(1)
	go func() {
		io.Copy(io.MultiWriter(stderr, &collectedStderr), processStderr)
		waitgroup.Done()
	}()
	io.Copy(io.MultiWriter(output, &collectedStdout), processStdout)
	waitgroup.Wait()
	err = process.Wait()
	processErrorString := ""
	if err != nil {
		processErrorString = err.Error()
	}
	return sampleExecutionResult{
		Stdin:        collectedStdin.String(),
		Stdout:       collectedStdout.String(),
		Stderr:       collectedStderr.String(),
		ProcessError: processErrorString,
	}
}
