package main

import (
	"fmt"
	"io/ioutil"
	"strings"

	"github.com/BurntSushi/toml"
)

// Sample contains input and output of a sample of a test for a competitive solution
type Sample struct {
	Input  string
	Output string
}

// Soitask is content of a Soitask file, a toml structured collection of testcases for a competitive program
type Soitask = map[string]map[string]Sample

func parseSample(soitaskPath, sampleName string) (Sample, error) {
	soitaskToml, err := ioutil.ReadFile(soitaskPath)
	if err != nil {
		return Sample{}, err
	}
	var soitask Soitask
	toml.Decode(string(soitaskToml), &soitask)

	tomlPath := strings.Split(sampleName, ".")
	if len(tomlPath) != 2 {
		return Sample{}, fmt.Errorf("Samplename '%v' doesn't fit a Soitask", sampleName)
	}
	return soitask[tomlPath[0]][tomlPath[1]], nil
}

func parseAllSamples(soitaskPath string) (map[string]Sample, error) {
	soitaskToml, err := ioutil.ReadFile(soitaskPath)
	if err != nil {
		return map[string]Sample{}, err
	}
	var soitask Soitask
	toml.Decode(string(soitaskToml), &soitask)
	samples := map[string]Sample{}

	for major, minormap := range soitask {

		for minor, sample := range minormap {
			samples[major+"."+minor] = sample
		}
	}
	return samples, nil
}
