import { Store } from "./store";

import * as path from "path";
// import * as fs from "fs-extra";
// import * as https from "https";
import { getWorkspaceOrShowError } from "./storeHelper";

export function getCompilerPath(store: Store): string {
	return getWorkspaceOrShowError(store).settings.settings.compilerPath;
}
export function getDebuggerPath(store: Store): string {
	return getWorkspaceOrShowError(store).settings.settings.debuggerPath;
}
export function getDebuggerFlavor(store: Store): "gdb" | "lldb" | null {
	let debuggerPath = getDebuggerPath(store);
	if (debuggerPath === null) {
		return null;
	}
	let flavor = path.basename(debuggerPath);
	if (flavor === "gdb" || flavor === "lldb") {
		return flavor;
	}
	return null;
}

export function getCppHeaderPath(store: Store): string {
	return getWorkspaceOrShowError(store).settings.settings.cppHeaderPath;
}

export function getSoiHeaderPath(store: Store): string {
	if (getWorkspaceOrShowError(store).settings.settings.useBundledSoiheaders) {
		return getWorkspaceOrShowError(store).settings.settings.soiHeaderPath;
	}
	return path.join(
		store.soicodeExtensionDataPath,
		"bundle",
		"soiheaders",
		"bundle",
		"soiheader"
	);
}

export function getCompilationFlags(store: Store): string[] {
	return getWorkspaceOrShowError(store).settings.settings.flags.split(" ");
}
