import { Store } from "./store";

import * as path from "path";
import * as child_process from "child_process";
import * as vscode from "vscode";
import { determinePlatform, executableFileEnding } from "./util";

export function getHelperPath(store: Store): string {
	return path.join(
		store.soicodeExtensionDistPath,
		`helper-${determinePlatform()}${executableFileEnding()}`
	);
}

export async function downloadCompilerBundle(store: Store) {
	return new Promise(async resolve => {
		let platform = determinePlatform();
		console.log("Fetching Helper binary for platform " + platform);
		let flavor = "soiheaders";
		let url = `https://blob.dolansoft.org/soicode/compilerbundle-${platform}-${flavor}.tar.xz`;
		let targetDir = path.join(store.soicodeExtensionDataPath, "bundle", flavor);
		let proc = child_process.execFile(getHelperPath(store), [
			"fetchBundle",
			"--url",
			url,
			"--targetDir",
			targetDir
		]);
		let stdout = "";
		proc.stdout.on("data", chunk => {
			stdout += chunk;
		});
		proc.on("exit", (code, signal) => {
			console.log(
				"fetching the compilerbundle finished, errorcode: " +
					code +
					"  stdout: " +
					stdout
			);
			if (code !== 0) {
				vscode.window.showErrorMessage(
					"Error fetching the compilerbundle, errorcode: " +
						code +
						"  stdout: " +
						stdout
				);
			}
		});
		resolve();
	});
}
