import { Store } from "./store";

import * as net from "net";
import { fspathToTasknameOrError } from "./soitask";

export interface SampleExecutionResult {
	Stdin: string;
	Stdout: string;
	Stderr: string;
	ProcessError: string;
}

function checkServerResponseTyped(
	o: any
): [string, string, SampleExecutionResult] | null {
	if (typeof o.Binarypath !== "string") {
		return null;
	}

	if (typeof o.Samplename !== "string") {
		return null;
	}
	if (typeof o.Result !== "object") {
		return null;
	}
	if (typeof o.Result.Stdin !== "string") {
		return null;
	}
	if (typeof o.Result.Stdout !== "string") {
		return null;
	}
	if (typeof o.Result.Stderr !== "string") {
		return null;
	}
	if (typeof o.Result.ProcessError !== "string") {
		return null;
	}

	return o;
}

export class HelperBinaryResultReceiver {
	tcpBuffer: string = "";
	store: Store;
	port: Number = -1;
	server: net.Server = new net.Server();

	constructor(store: Store) {
		this.store = store;
	}

	startServer(port: Number) {
		this.server = net.createServer(this.processPacket.bind(this));
		this.server.listen(port);
		this.port = port;
	}

	processPacket(s: net.Socket) {
		let runner = this;
		s.on(
			"data",
			function(data: Buffer) {
				runner.tcpBuffer = runner.tcpBuffer + data.toString();
				if (runner.tcpBuffer.indexOf("\n") === -1) {
					return;
				}
				runner.tcpBuffer.split("\n").forEach(result => {
					if (result !== "") {
						runner.processResult(result);
					}
				});
			}.bind(this)
		);
	}

	processResult(this: HelperBinaryResultReceiver, res: string) {
		let parsed = checkServerResponseTyped(JSON.parse(res));
		if (parsed === null) {
			this.store.handleError(
				"Downloading dependencies",
				"Downloaded a invalid compiler bundle",
				Error("invalid package received")
			);
		}
		let [binarypath, samplename, result] = parsed;
		let taskname = fspathToTasknameOrError(this.store, binarypath);
		this.store.addExecutionResult(taskname, samplename, result);
	}
}
