import * as vscode from "vscode";
import { cppTemplate } from "../template/cppTemplate";
import { Store } from "../store";

export async function insertCppTemplate() {
	let insertionLocation = new vscode.Range(0, 0, 0, 0);
	let snippet = new vscode.SnippetString(cppTemplate());

	if (vscode.window.activeTextEditor === undefined) {
		vscode.window.showErrorMessage(
			"Can only insert template if a file is open"
		);
		return;
	}
	vscode.window.activeTextEditor.insertSnippet(snippet, insertionLocation);
}

export class InsertCppTemplateLensProvider implements vscode.CodeLensProvider {
	store: Store;
	constructor(store: Store) {
		this.store = store;
	}
	async provideCodeLenses(
		document: vscode.TextDocument
	): Promise<vscode.CodeLens[]> {
		let topOfDocument = new vscode.Range(0, 0, 0, 0);

		let c: vscode.Command = {
			command: "soicode.addCppTemplate",
			title: "Insert C++ Template"
		};

		if (document.getText().trim().length === 0) {
			let codeLens = new vscode.CodeLens(topOfDocument, c);

			return [codeLens];
		}
		return [];
	}
}

export function subscribeInsertCppTemplateLens(
	context: vscode.ExtensionContext,
	store: Store
) {
	let docSelector = {
		language: "cpp",
		scheme: "file"
	};

	let codeLensProviderDisposable = vscode.languages.registerCodeLensProvider(
		docSelector,
		new InsertCppTemplateLensProvider(store)
	);

	context.subscriptions.push(codeLensProviderDisposable);
}
