import * as vscode from "vscode";
import { soitaskTemplate } from "../template/soitaskTemplate";
import { Store } from "../store";

export async function insertSoitaskTemplate() {
	let insertionLocation = new vscode.Range(0, 0, 0, 0);
	let snippet = new vscode.SnippetString(soitaskTemplate());

	if (vscode.window.activeTextEditor === undefined) {
		vscode.window.showErrorMessage(
			"Can only insert template if a file is open"
		);
		return;
	}
	vscode.window.activeTextEditor.insertSnippet(snippet, insertionLocation);
}

export class InsertSoitaskTemplateLensProvider
	implements vscode.CodeLensProvider {
	store: Store;

	constructor(store: Store) {
		this.store = store;
	}

	async provideCodeLenses(
		document: vscode.TextDocument
	): Promise<vscode.CodeLens[]> {
		let topOfDocument = new vscode.Range(0, 0, 0, 0);

		let c: vscode.Command = {
			command: "soicode.addSoitaskTemplate",
			title: "Insert Soitask Template"
		};

		if (document.getText().trim().length === 0) {
			let codeLens = new vscode.CodeLens(topOfDocument, c);

			return [codeLens];
		}
		return [];
	}
}

export function subscribeInsertSoitaskTemplateLens(
	context: vscode.ExtensionContext,
	store: Store
) {
	let docSelector = {
		language: "stoml",
		scheme: "file"
	};

	let codeLensProviderDisposable = vscode.languages.registerCodeLensProvider(
		docSelector,
		new InsertSoitaskTemplateLensProvider(store)
	);

	context.subscriptions.push(codeLensProviderDisposable);
}
