import * as vscode from "vscode";
import { Store } from "./store";
import * as path from "path";
import { toSortedKeys } from "./util";

export class SamplesTreeViewProvider
	implements vscode.TreeDataProvider<string> {
	store: Store;

	triggerUpdate = new vscode.EventEmitter<string | undefined>();
	onDidChangeTreeData = this.triggerUpdate.event;

	constructor(state: Store) {
		this.store = state;
		this.updateData(undefined);
		this.store.allSampleChangeSubscribers.push(
			this.updateData.bind(this, undefined)
		);
		this.store.sampleUpdateSubscriber.push(this.updateData.bind(this));
	}

	getTreeItem(this: SamplesTreeViewProvider, sample: string): vscode.TreeItem {
		let item = new vscode.TreeItem(
			sample,
			vscode.TreeItemCollapsibleState.None
		);
		item.contextValue = "sample";
		item.command = {
			command: "soicode.openSample",
			title: "Open Sample",
			arguments: [sample],
			tooltip: "Open Sample"
		}; // todo register as command

		// switch(this.state.samples.get){
		{
			item.iconPath = {
				light: path.join(
					this.store.soicodeExtensionImagePath,
					"./icons/light/task.svg"
				),
				dark: path.join(
					this.store.soicodeExtensionImagePath,
					"./icons/dark/task.svg"
				)
			};
		}
		return item;
	}

	updateData(this: SamplesTreeViewProvider, node: string | undefined) {
		this.triggerUpdate.fire(node);
	}

	getChildren(this: SamplesTreeViewProvider, elem?: string): string[] {
		if (elem === undefined) {
			return toSortedKeys(this.store.samples);
		} else {
			return [];
		}
	}
}
