import { Store } from "./store";

import * as vscode from "vscode";
import { SoiWorkspace } from "./soiworkspace";
import { SoitaskFiles } from "./soitask";

export function getWorkspaceOrShowError(store: Store): SoiWorkspace {
	if (
		store.workspace === "NoFolderOpen" ||
		store.workspace === "NoSOIWorkspace"
	) {
		vscode.window.showErrorMessage(
			"Make sure you are in a SOI workspace before executing commands"
		);
		throw new Error(
			"Make sure you are in a SOI workspace before executing commands"
		);
	}
	return store.workspace;
}

export function listPartialTasksOrError(store: Store): SoitaskFiles[] {
	let workspace = getWorkspaceOrShowError(store);
	return Array.from(workspace.task.entries())
		.sort()
		.map(entry => entry[1]);
}

export function listFullTasksOrError(store: Store): SoitaskFiles[] {
	let workspace = getWorkspaceOrShowError(store);
	return Array.from(workspace.task.entries())
		.sort()
		.filter(
			entry =>
				entry[1].solutionFsPath !== null && entry[1].soitaskFsPath !== null
		)
		.map(entry => entry[1]);
}

export function getSoitaskFilesOfFulltaskOrError(
	store: Store,
	taskname: string
): SoitaskFiles {
	let workspace = getWorkspaceOrShowError(store);
	let soitaskFiles = workspace.task.get(taskname);
	if (soitaskFiles === undefined) {
		vscode.window.showErrorMessage("The task you are using does not exist");
		throw new Error("The task you are using does not exist");
	}
	if (soitaskFiles.solutionFsPath === null) {
		vscode.window.showErrorMessage(
			"The task you are using does not have a solution file"
		);
		throw new Error("The task you are using does not have a solution file");
	}
	if (soitaskFiles.soitaskFsPath === null) {
		vscode.window.showErrorMessage(
			"The task you are using does not have a soitask"
		);
		throw new Error("The task you are using does not have a soitask");
	}
	return soitaskFiles;
}
